jacinle.jit.cext.travis
=======================

.. automodule:: jacinle.jit.cext.travis

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      auto_travis
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: auto_travis


